import { ICalcXy, IGridItemWidthHeight } from '@/core/interfaces/grid-item.interfaces';
import { IPositionParameters } from '@/core/interfaces/layout-data.interface';
/**
 * Compute the column width.
 *
 * @param  {IPositionParameters} positionParams  Parameters of grid needed for coordinates calculations.
 * @return {Number}                               Column width (in pixels).
 */
export declare const calcGridColWidth: (positionParams: IPositionParameters) => number;
/**
 * Compute an item width and height.
 *
 * @param  {IPositionParameters} positionParams Parameters of grid needed for coordinates calculations.
 * @param  {Number}                      w       W coordinate in grid units.
 * @param  {Number}                      h       H coordinate in grid units.
 * @return {IGridItemWidthHeight}                width and height (in pixels).
 */
export declare const calcItemSize: (positionParams: IPositionParameters, w: number, h: number) => IGridItemWidthHeight;
/**
 * Translate x and y coordinates from pixels to grid units.
 *
 * @param  {IPositionParameters} positionParams  Parameters of grid needed for coordinates calculations.
 * @param  {Number}               top             Top position (relative to parent) in pixels.
 * @param  {Number}               left            Left position (relative to parent) in pixels.
 * @param  {Number}               w               W coordinate in grid units.
 * @param  {Number}               h               H coordinate in grid units.
 * @return {ICalcXy}                              x and y in grid units.
 */
export declare const calcXY: (positionParams: IPositionParameters, top: number, left: number, w: number, h: number) => ICalcXy;
